@@ -1,8 +1,9 @@
 package Net::Twitter::Role::AppAuth;
-$Net::Twitter::Role::AppAuth::VERSION = '4.01041';
+$Net::Twitter::Role::AppAuth::VERSION = '4.01042';
 use Moose::Role;
 use Carp::Clan   qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 use HTTP::Request::Common qw/POST/;
+use Net::Twitter::Types;
 
 requires qw/_add_authorization_header ua from_json/;
 
@@ -30,9 +31,10 @@ has [ qw/consumer_key consumer_secret/ ] => (
 
 # url attributes
 has [ qw/request_token_url invalidate_token_url/ ] => (
-    isa      => 'Str',
-    is       => 'rw',
+    isa      => 'Net::Twitter::Types::URI',
+    is       => 'ro',
     required => 1,
+    coerce   => 1,
 );
 
 has access_token => (
@@ -117,7 +119,7 @@ Net::Twitter::Role::AppAuth - OAuth2 Application Only Authentication
 
 =head1 VERSION
 
-version 4.01041
+version 4.01042
 
 =head1 SYNOPSIS
 
