@@ -1,11 +1,12 @@
 package Net::Twitter::Role::OAuth;
-$Net::Twitter::Role::OAuth::VERSION = '4.01041';
+$Net::Twitter::Role::OAuth::VERSION = '4.01042';
 use Moose::Role;
 use HTTP::Request::Common;
 use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 use URI;
 use Digest::SHA;
 use List::Util qw/first/;
+use Net::Twitter::Types;
 
 requires qw/_add_authorization_header ua/;
 
@@ -34,14 +35,14 @@ around BUILDARGS => sub {
 has consumer_key    => ( isa => 'Str', is => 'ro', required => 1 );
 has consumer_secret => ( isa => 'Str', is => 'ro', required => 1 );
 
-# url attributes
-for my $attribute ( qw/authentication_url authorization_url request_token_url access_token_url xauth_url/ ) {
-    has $attribute => (
-        isa    => 'Str', is => 'rw', required => 1,
-        # inflate urls to URI objects when read
-        reader => { $attribute => sub { URI->new(shift->{$attribute}) } },
-    );
-}
+# URI attributes
+has [ qw/authentication_url authorization_url request_token_url
+         access_token_url xauth_url/ ] => (
+    isa      => 'Net::Twitter::Types::URI',
+    is       => 'ro',
+    required => 1,
+    coerce   => 1,
+);
 
 # token attributes
 for my $attribute ( qw/access_token access_token_secret request_token request_token_secret/ ) {
@@ -266,7 +267,7 @@ Net::Twitter::Role::OAuth - Net::Twitter role that provides OAuth instead of Bas
 
 =head1 VERSION
 
-version 4.01041
+version 4.01042
 
 =head1 SYNOPSIS
 
